==> aws-cdk-lib-2.183.0-sources.jar: software/amazon/awscdk/services/kinesisfirehose/S3Bucket.java <==
package software.amazon.awscdk.services.kinesisfirehose;

/**
 * An S3 bucket destination for data from a Kinesis Data Firehose delivery stream.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Bucket bucket;
 * // Provide a Lambda function that will transform records before delivery, with custom
 * // buffering and retry configuration
 * Function lambdaFunction = Function.Builder.create(this, "Processor")
 *         .runtime(Runtime.NODEJS_LATEST)
 *         .handler("index.handler")
 *         .code(Code.fromAsset(join(__dirname, "process-records")))
 *         .build();
 * LambdaFunctionProcessor lambdaProcessor = LambdaFunctionProcessor.Builder.create(lambdaFunction)
 *         .bufferInterval(Duration.minutes(5))
 *         .bufferSize(Size.mebibytes(5))
 *         .retries(5)
 *         .build();
 * S3Bucket s3Destination = S3Bucket.Builder.create(bucket)
 *         .processor(lambdaProcessor)
 *         .build();
 * DeliveryStream.Builder.create(this, "Delivery Stream")
 *         .destination(s3Destination)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.106.0 (build e852934)", date = "2025-03-12T01:36:40.440Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_kinesisfirehose.S3Bucket")
public class S3Bucket extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.kinesisfirehose.IDestination {

    protected S3Bucket(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3Bucket(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param bucket This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public S3Bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.kinesisfirehose.S3BucketProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required"), props });
    }

    /**
     * @param bucket This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public S3Bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required") });
    }

    /**
     * Binds this destination to the Kinesis Data Firehose delivery stream.
     * <p>
     * Implementers should use this method to bind resources to the stack and initialize values using the provided stream.
     * <p>
     * @param scope This parameter is required.
     * @param _options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.kinesisfirehose.DestinationConfig bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.kinesisfirehose.DestinationBindOptions _options) {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kinesisfirehose.DestinationConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(_options, "_options is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.kinesisfirehose.S3Bucket}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.kinesisfirehose.S3Bucket> {
        /**
         * @return a new instance of {@link Builder}.
         * @param bucket This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.services.s3.IBucket bucket) {
            return new Builder(bucket);
        }

        private final software.amazon.awscdk.services.s3.IBucket bucket;
        private software.amazon.awscdk.services.kinesisfirehose.S3BucketProps.Builder props;

        private Builder(final software.amazon.awscdk.services.s3.IBucket bucket) {
            this.bucket = bucket;
        }

        /**
         * The length of time that Firehose buffers incoming data before delivering it to the S3 bucket.
         * <p>
         * Minimum: Duration.seconds(0)
         * Maximum: Duration.seconds(900)
         * <p>
         * Default: Duration.seconds(300)
         * <p>
         * @return {@code this}
         * @param bufferingInterval The length of time that Firehose buffers incoming data before delivering it to the S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bufferingInterval(final software.amazon.awscdk.Duration bufferingInterval) {
            this.props().bufferingInterval(bufferingInterval);
            return this;
        }

        /**
         * The size of the buffer that Kinesis Data Firehose uses for incoming data before delivering it to the S3 bucket.
         * <p>
         * Minimum: Size.mebibytes(1)
         * Maximum: Size.mebibytes(128)
         * <p>
         * Default: Size.mebibytes(5)
         * <p>
         * @return {@code this}
         * @param bufferingSize The size of the buffer that Kinesis Data Firehose uses for incoming data before delivering it to the S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bufferingSize(final software.amazon.awscdk.Size bufferingSize) {
            this.props().bufferingSize(bufferingSize);
            return this;
        }

        /**
         * The type of compression that Kinesis Data Firehose uses to compress the data that it delivers to the Amazon S3 bucket.
         * <p>
         * The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift
         * destinations because they are not supported by the Amazon Redshift COPY operation
         * that reads from the S3 bucket.
         * <p>
         * Default: - UNCOMPRESSED
         * <p>
         * @return {@code this}
         * @param compression The type of compression that Kinesis Data Firehose uses to compress the data that it delivers to the Amazon S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder compression(final software.amazon.awscdk.services.kinesisfirehose.Compression compression) {
            this.props().compression(compression);
            return this;
        }

        /**
         * A prefix that Kinesis Data Firehose evaluates and adds to records before writing them to S3.
         * <p>
         * This prefix appears immediately following the bucket name.
         * <p>
         * Default: "YYYY/MM/DD/HH"
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html">https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html</a>
         * @param dataOutputPrefix A prefix that Kinesis Data Firehose evaluates and adds to records before writing them to S3. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dataOutputPrefix(final java.lang.String dataOutputPrefix) {
            this.props().dataOutputPrefix(dataOutputPrefix);
            return this;
        }

        /**
         * The AWS KMS key used to encrypt the data that it delivers to your Amazon S3 bucket.
         * <p>
         * Default: - Data is not encrypted.
         * <p>
         * @return {@code this}
         * @param encryptionKey The AWS KMS key used to encrypt the data that it delivers to your Amazon S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.IKey encryptionKey) {
            this.props().encryptionKey(encryptionKey);
            return this;
        }

        /**
         * A prefix that Kinesis Data Firehose evaluates and adds to failed records before writing them to S3.
         * <p>
         * This prefix appears immediately following the bucket name.
         * <p>
         * Default: "YYYY/MM/DD/HH"
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html">https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html</a>
         * @param errorOutputPrefix A prefix that Kinesis Data Firehose evaluates and adds to failed records before writing them to S3. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder errorOutputPrefix(final java.lang.String errorOutputPrefix) {
            this.props().errorOutputPrefix(errorOutputPrefix);
            return this;
        }

        /**
         * Configuration that determines whether to log errors during data transformation or delivery failures, and specifies the CloudWatch log group for storing error logs.
         * <p>
         * Default: - errors will be logged and a log group will be created for you.
         * <p>
         * @return {@code this}
         * @param loggingConfig Configuration that determines whether to log errors during data transformation or delivery failures, and specifies the CloudWatch log group for storing error logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder loggingConfig(final software.amazon.awscdk.services.kinesisfirehose.ILoggingConfig loggingConfig) {
            this.props().loggingConfig(loggingConfig);
            return this;
        }

        /**
         * The data transformation that should be performed on the data before writing to the destination.
         * <p>
         * Default: - no data transformation will occur.
         * <p>
         * @return {@code this}
         * @param processor The data transformation that should be performed on the data before writing to the destination. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder processor(final software.amazon.awscdk.services.kinesisfirehose.IDataProcessor processor) {
            this.props().processor(processor);
            return this;
        }

        /**
         * The IAM role associated with this destination.
         * <p>
         * Assumed by Kinesis Data Firehose to invoke processors and write to destinations
         * <p>
         * Default: - a role will be created with default permissions.
         * <p>
         * @return {@code this}
         * @param role The IAM role associated with this destination. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder role(final software.amazon.awscdk.services.iam.IRole role) {
            this.props().role(role);
            return this;
        }

        /**
         * The configuration for backing up source records to S3.
         * <p>
         * Default: - source records will not be backed up to S3.
         * <p>
         * @return {@code this}
         * @param s3Backup The configuration for backing up source records to S3. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3Backup(final software.amazon.awscdk.services.kinesisfirehose.DestinationS3BackupProps s3Backup) {
            this.props().s3Backup(s3Backup);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.kinesisfirehose.S3Bucket}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.kinesisfirehose.S3Bucket build() {
            return new software.amazon.awscdk.services.kinesisfirehose.S3Bucket(
                this.bucket,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.kinesisfirehose.S3BucketProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.kinesisfirehose.S3BucketProps.Builder();
            }
            return this.props;
        }
    }
}

==> aws-cdk-lib-2.184.1-sources.jar: software/amazon/awscdk/services/kinesisfirehose/S3Bucket.java <==
package software.amazon.awscdk.services.kinesisfirehose;

/**
 * An S3 bucket destination for data from a Kinesis Data Firehose delivery stream.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.kinesisfirehose.*;
 * Bucket bucket = new Bucket(this, "MyBucket");
 * DeliveryStream stream = DeliveryStream.Builder.create(this, "MyStream")
 *         .destination(new S3Bucket(bucket))
 *         .build();
 * TopicRule topicRule = TopicRule.Builder.create(this, "TopicRule")
 *         .sql(IotSql.fromStringAsVer20160323("SELECT * FROM 'device/+/data'"))
 *         .actions(List.of(
 *             FirehosePutRecordAction.Builder.create(stream)
 *                     .batchMode(true)
 *                     .recordSeparator(FirehoseRecordSeparator.NEWLINE)
 *                     .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.109.0 (build c221850)", date = "2025-03-14T03:25:00.404Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_kinesisfirehose.S3Bucket")
public class S3Bucket extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.kinesisfirehose.IDestination {

    protected S3Bucket(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3Bucket(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param bucket This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public S3Bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.kinesisfirehose.S3BucketProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required"), props });
    }

    /**
     * @param bucket This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public S3Bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required") });
    }

    /**
     * Binds this destination to the Kinesis Data Firehose delivery stream.
     * <p>
     * Implementers should use this method to bind resources to the stack and initialize values using the provided stream.
     * <p>
     * @param scope This parameter is required.
     * @param _options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.kinesisfirehose.DestinationConfig bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.kinesisfirehose.DestinationBindOptions _options) {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kinesisfirehose.DestinationConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(_options, "_options is required") });
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.kinesisfirehose.S3Bucket}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.kinesisfirehose.S3Bucket> {
        /**
         * @return a new instance of {@link Builder}.
         * @param bucket This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.services.s3.IBucket bucket) {
            return new Builder(bucket);
        }

        private final software.amazon.awscdk.services.s3.IBucket bucket;
        private software.amazon.awscdk.services.kinesisfirehose.S3BucketProps.Builder props;

        private Builder(final software.amazon.awscdk.services.s3.IBucket bucket) {
            this.bucket = bucket;
        }

        /**
         * The length of time that Firehose buffers incoming data before delivering it to the S3 bucket.
         * <p>
         * Minimum: Duration.seconds(0)
         * Maximum: Duration.seconds(900)
         * <p>
         * Default: Duration.seconds(300)
         * <p>
         * @return {@code this}
         * @param bufferingInterval The length of time that Firehose buffers incoming data before delivering it to the S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bufferingInterval(final software.amazon.awscdk.Duration bufferingInterval) {
            this.props().bufferingInterval(bufferingInterval);
            return this;
        }

        /**
         * The size of the buffer that Kinesis Data Firehose uses for incoming data before delivering it to the S3 bucket.
         * <p>
         * Minimum: Size.mebibytes(1)
         * Maximum: Size.mebibytes(128)
         * <p>
         * Default: Size.mebibytes(5)
         * <p>
         * @return {@code this}
         * @param bufferingSize The size of the buffer that Kinesis Data Firehose uses for incoming data before delivering it to the S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bufferingSize(final software.amazon.awscdk.Size bufferingSize) {
            this.props().bufferingSize(bufferingSize);
            return this;
        }

        /**
         * The type of compression that Kinesis Data Firehose uses to compress the data that it delivers to the Amazon S3 bucket.
         * <p>
         * The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift
         * destinations because they are not supported by the Amazon Redshift COPY operation
         * that reads from the S3 bucket.
         * <p>
         * Default: - UNCOMPRESSED
         * <p>
         * @return {@code this}
         * @param compression The type of compression that Kinesis Data Firehose uses to compress the data that it delivers to the Amazon S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder compression(final software.amazon.awscdk.services.kinesisfirehose.Compression compression) {
            this.props().compression(compression);
            return this;
        }

        /**
         * A prefix that Kinesis Data Firehose evaluates and adds to records before writing them to S3.
         * <p>
         * This prefix appears immediately following the bucket name.
         * <p>
         * Default: "YYYY/MM/DD/HH"
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html">https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html</a>
         * @param dataOutputPrefix A prefix that Kinesis Data Firehose evaluates and adds to records before writing them to S3. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dataOutputPrefix(final java.lang.String dataOutputPrefix) {
            this.props().dataOutputPrefix(dataOutputPrefix);
            return this;
        }

        /**
         * The AWS KMS key used to encrypt the data that it delivers to your Amazon S3 bucket.
         * <p>
         * Default: - Data is not encrypted.
         * <p>
         * @return {@code this}
         * @param encryptionKey The AWS KMS key used to encrypt the data that it delivers to your Amazon S3 bucket. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.IKey encryptionKey) {
            this.props().encryptionKey(encryptionKey);
            return this;
        }

        /**
         * A prefix that Kinesis Data Firehose evaluates and adds to failed records before writing them to S3.
         * <p>
         * This prefix appears immediately following the bucket name.
         * <p>
         * Default: "YYYY/MM/DD/HH"
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html">https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html</a>
         * @param errorOutputPrefix A prefix that Kinesis Data Firehose evaluates and adds to failed records before writing them to S3. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder errorOutputPrefix(final java.lang.String errorOutputPrefix) {
            this.props().errorOutputPrefix(errorOutputPrefix);
            return this;
        }

        /**
         * Configuration that determines whether to log errors during data transformation or delivery failures, and specifies the CloudWatch log group for storing error logs.
         * <p>
         * Default: - errors will be logged and a log group will be created for you.
         * <p>
         * @return {@code this}
         * @param loggingConfig Configuration that determines whether to log errors during data transformation or delivery failures, and specifies the CloudWatch log group for storing error logs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder loggingConfig(final software.amazon.awscdk.services.kinesisfirehose.ILoggingConfig loggingConfig) {
            this.props().loggingConfig(loggingConfig);
            return this;
        }

        /**
         * The data transformation that should be performed on the data before writing to the destination.
         * <p>
         * Default: - no data transformation will occur.
         * <p>
         * @return {@code this}
         * @param processor The data transformation that should be performed on the data before writing to the destination. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder processor(final software.amazon.awscdk.services.kinesisfirehose.IDataProcessor processor) {
            this.props().processor(processor);
            return this;
        }

        /**
         * The IAM role associated with this destination.
         * <p>
         * Assumed by Kinesis Data Firehose to invoke processors and write to destinations
         * <p>
         * Default: - a role will be created with default permissions.
         * <p>
         * @return {@code this}
         * @param role The IAM role associated with this destination. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder role(final software.amazon.awscdk.services.iam.IRole role) {
            this.props().role(role);
            return this;
        }

        /**
         * The configuration for backing up source records to S3.
         * <p>
         * Default: - source records will not be backed up to S3.
         * <p>
         * @return {@code this}
         * @param s3Backup The configuration for backing up source records to S3. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder s3Backup(final software.amazon.awscdk.services.kinesisfirehose.DestinationS3BackupProps s3Backup) {
            this.props().s3Backup(s3Backup);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.kinesisfirehose.S3Bucket}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.kinesisfirehose.S3Bucket build() {
            return new software.amazon.awscdk.services.kinesisfirehose.S3Bucket(
                this.bucket,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.kinesisfirehose.S3BucketProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.kinesisfirehose.S3BucketProps.Builder();
            }
            return this.props;
        }
    }
}
